@@ -25,26 +25,24 @@ class UpdateTableThemeRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateTableTheme')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Name(self):
+	def get_Name(self): # String
 		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
-
-	def get_ThemeId(self):
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
+	def get_ThemeId(self): # Long
 		return self.get_query_params().get('ThemeId')
 
-	def set_ThemeId(self,ThemeId):
-		self.add_query_param('ThemeId',ThemeId)
-
-	def get_ProjectId(self):
+	def set_ThemeId(self, ThemeId):  # Long
+		self.add_query_param('ThemeId', ThemeId)
+	def get_ProjectId(self): # Long
 		return self.get_query_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
-		self.add_query_param('ProjectId',ProjectId)
\ No newline at end of file
+	def set_ProjectId(self, ProjectId):  # Long
+		self.add_query_param('ProjectId', ProjectId)
